@@ -19,11 +19,11 @@ use Carp;
 ########################################################################
 
 #### Module Dependencies ###############################################
-use CGI::Uricode qw(uri_decode uri_escape uri_unescape);
+use CGI::Uricode qw(uri_escape uri_unescape);
 ########################################################################
 
 #### Constants #########################################################
-our $VERSION = '0.11'; # 2005-11-08 (since 2003-04-09)
+our $VERSION = '0.12'; # 2005-11-10 (since 2003-04-09)
 ########################################################################
 
 =head1 NAME
